Index: firmware/FTM/ftm_definitions.vhd
===================================================================
--- firmware/FTM/ftm_definitions.vhd	(revision 10228)
+++ firmware/FTM/ftm_definitions.vhd	(revision 10229)
@@ -296,11 +296,7 @@
   );
 
-
-
-
   -- Light pulser interface
-  constant low_PLC : integer := 16;     -- minimal pulse duration in units of 4
-                                        -- ns
-
-  
+  constant low_PLC : integer := 16;   -- minimal pulse duration in units of 4 ns
+  constant width_PLC : integer := 6;  -- counter width pulse duration 
+                                    
 end ftm_constants;
